<?php

namespace Realestate\Seo\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Realestate\Seo\Http\Requests\SeoRequest;
use Realestate\Seo\Interfaces\SeoRepositoryInterface;
use Realestate\Seo\Models\Seo;
use Realestate\Seo\Forms\Seo as Form;

/**
 * APIController  class for seo.
 */
class SeoAPIController extends BaseController
{

    /**
     * Initialize seo resource controller.
     *
     * @param type SeoRepositoryInterface $seo
     *
     * @return null
     */
    public function __construct(SeoRepositoryInterface $seo)
    {
        parent::__construct();
        $this->repository = $seo;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Realestate\Seo\Repositories\Criteria\SeoResourceCriteria::class);
    }

    /**
     * Display a list of seo.
     *
     * @return Response
     */
    public function index(SeoRequest $request)
    {
        return $this->repository
            ->setPresenter(\Realestate\Seo\Repositories\Presenter\SeoPresenter::class)
            ->paginate();
    }

    /**
     * Display seo.
     *
     * @param Request $request
     * @param Model   $seo
     *
     * @return Response
     */
    public function show(SeoRequest $request, Seo $seo)
    {
        return $seo->setPresenter(\Realestate\Seo\Repositories\Presenter\SeoListPresenter::class);
        ;
    }

    /**
     * Create new seo.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(SeoRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('seo::seo.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('seo/seo/' . $seo->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('seo/seo');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the seo.
     *
     * @param Request $request
     * @param Model   $seo
     *
     * @return Response
     */
    public function update(SeoRequest $request, Seo $seo)
    {
        try {
            $data = $request->all();

            $seo->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('seo::seo.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('seo/seo/' . $seo->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('seo/seo/' . $seo->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the seo.
     *
     * @param Model   $seo
     *
     * @return Response
     */
    public function destroy(SeoRequest $request, Seo $seo)
    {
        try {
            $seo->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('seo::seo.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('seo/seo/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('seo/seo/' . $seo->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
